# A acceleration library for DeepCache algorithm

## Reference

DeepCache originality is here https://github.com/horseee/DeepCache
```
@article{ma2023deepcache,
  title={DeepCache: Accelerating Diffusion Models for Free},
  author={Ma, Xinyin and Fang, Gongfan and Wang, Xinchao},
  journal={arXiv preprint arXiv:2312.00858},
  year={2023}
}
```
